readv

Function readv 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn readv( fd: c_int, iov: *const iovec, iovcnt: c_int, ) -> ssize_t
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/readv.html.

Equivalent to read() but places the input data into the iovcnt buffers specified by the members of the iov array.

When successful, returns a non-negative number indicating the number of bytes actually read. Upon failure, returns -1.