#[unsafe(no_mangle)]pub unsafe extern "C" fn writev(
fd: c_int,
iov: *const iovec,
iovcnt: c_int,
) -> ssize_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/writev.html.
Equivalent to write() but shall gather output data from the iovcnt
buffers specified by the members of the iov array.
When successful, returns a non-negative number indicating the number of
bytes actually written to the file associated with fildes. Upon failure,
returns -1.